<?php

//Add project post type to page builder defaults
function create_siteorgin_defaults($defaults){
	// Post types
	$defaults['post-types'] = array('page', 'post', 'project');
	return $defaults;
}
add_filter( 'siteorigin_panels_settings_defaults', 'create_siteorgin_defaults' );

//Remove the built-in posts carousel widget
function create_panels_widgets( $widgets ){
	unset($widgets['SiteOrigin_Widget_PostCarousel_Widget']);
	return $widgets;
}
add_filter( 'siteorigin_panels_widgets', 'create_panels_widgets', 11);



function create_filter_siteorigin_active_widgets($active){
    $active['so-price-table-widget'] = true;
	$active['so-headline-widget'] = true;
	$active['so-social-media-buttons-widget'] = true;
	$active['so-post-carousel-widget'] = false;
    return $active;
}
add_filter('siteorigin_widgets_active_widgets', 'create_filter_siteorigin_active_widgets');

function create_siteoriginpanels_row_attributes($attr, $row) {
  if(!empty($row['style']['class'])) {
    if(empty($attr['style'])) $attr['style'] = '';
    $attr['style'] .= 'margin-bottom: 0px;';
    $attr['style'] .= 'margin-left: 0px;';
    $attr['style'] .= 'margin-right: 0px;';
  }

  return $attr;
}
add_filter('siteorigin_panels_row_attributes', 'create_siteoriginpanels_row_attributes', 10, 2);


//Add custom row styles
function create_panels_row_background_styles($fields) {
 
  $fields['custom_row_id'] = array(
	     'name'      => __('Custom ID', 'create'),
	     'type'      => 'text',
	     'group'     => 'attributes',
	     'priority'  => 1,
  );

  $fields['equal_column_height'] = array(
        'name'      => __('Equal Column Height', 'create'),
        'type'      => 'select',
        'group'     => 'layout',
        'default'   => 'no',
        'priority'  => 10,
        'options'   => array(
             "no"      => __("No", "create"),
             "yes"   => __("Yes", "create"),
              ),
  );

  $fields['padding_top'] = array(
        'name'      => __('Padding Top', 'create'),
        'type'      => 'measurement',
        'group'     => 'layout',
        'priority'  => 8,
  );
  $fields['padding_bottom'] = array(
        'name'      => __('Padding Bottom', 'create'),
        'type'      => 'measurement',
        'group'     => 'layout',
        'priority'  => 8.5,
  );
  $fields['padding_left'] = array(
        'name'      => __('Padding Left', 'create'),
        'type'      => 'measurement',
        'group'     => 'layout',
        'priority'  => 9,
      );
  $fields['padding_right'] = array(
        'name'      => __('Padding Right', 'create'),
        'type'      => 'measurement',
        'group'     => 'layout',
        'priority'  => 9,
      );
  $fields['background_image'] = array(
        'name'      => __('Background Image', 'create'),
        'group'     => 'design',
        'type'      => 'image',
        'priority'  => 5,
      );
  $fields['background_image_position'] = array(
        'name'      => __('Background Image Position', 'create'),
        'type'      => 'select',
        'group'     => 'design',
        'default'   => 'center top',
        'priority'  => 6,
        'options'   => array(
               "left top"       => __("Left Top", "create"),
               "left center"    => __("Left Center", "create"),
               "left bottom"    => __("Left Bottom", "create"),
               "center top"     => __("Center Top", "create"),
               "center center"  => __("Center Center", "create"),
               "center bottom"  => __("Center Bottom", "create"),
               "right top"      => __("Right Top", "create"),
               "right center"   => __("Right Center", "create"),
               "right bottom"   => __("Right Bottom", "create")
                ),
      );
  $fields['background_image_style'] = array(
        'name'      => __('Background Image Style', 'create'),
        'type'      => 'select',
        'group'     => 'design',
        'default'   => 'cover',
        'priority'  => 6,
        'options'   => array(
             "cover"      => __("Cover", "create"),
             "no-repeat"  => __("No Repeat", "create"),
             "repeat"     => __("Repeat", "create"),
             "repeat-x"   => __("Repeat-X", "create"),
             "repeat-y"   => __("Repeat-y", "create"),
              ),
        );
  $fields['border_top'] = array(
        'name'      => __('Border Top Size', 'create'),
        'type'      => 'measurement',
        'group'     => 'design',
        'priority'  => 8,
  );
  $fields['border_top_color'] = array(
        'name'      => __('Border Top Color', 'create'),
        'type'      => 'color',
        'group'     => 'design',
        'priority'  => 8.5,
      );
  $fields['border_bottom'] = array(
        'name'      => __('Border Bottom Size', 'create'),
        'type'      => 'measurement',
        'group'     => 'design',
        'priority'  => 9,
  );
  $fields['border_bottom_color'] = array(
        'name' => __('Border Bottom Color', 'create'),
        'type' => 'color',
        'group' => 'design',
        'priority' => 9.5,
  );
  return $fields;
}
add_filter('siteorigin_panels_row_style_fields', 'create_panels_row_background_styles');

function create_panels_remove_row_background_styles($fields) {
 unset( $fields['background_image_attachment'] );
 unset( $fields['background_display'] );
 unset( $fields['padding'] );
 unset( $fields['border_color'] );
 return $fields;
}
add_filter('siteorigin_panels_row_style_fields', 'create_panels_remove_row_background_styles');

function create_panels_row_background_styles_attributes($attributes, $args) {

  if(!empty($args['background_image'])) {
    $url = wp_get_attachment_image_src( $args['background_image'], 'full' );
	$unique_class = 'row-'.uniqid();
    if(empty($url) || $url[0] == site_url() ) {
		$bg_img = $args['background_image'];
      } else {
		$bg_img = $url[0];
      }
	  $attributes['style'] .= 'background-image: url(' . $bg_img . ');';
      if(!empty($args['background_image_style'])) {
            switch( $args['background_image_style'] ) {
              case 'no-repeat':
                $attributes['style'] .= 'background-repeat: no-repeat;';
                break;
              case 'repeat':
                $attributes['style'] .= 'background-repeat: repeat;';
                break;
              case 'repeat-x':
                $attributes['style'] .= 'background-repeat: repeat-x;';
                break;
              case 'repeat-y':
                $attributes['style'] .= 'background-repeat: repeat-y;';
                break;
              case 'cover':
                $attributes['style'] .= 'background-size: cover;';
                break;
              case 'parallax':
				//$attributes['style'] = '';
                $attributes['class'][] .= 'parallax-section';
				$attributes['class'][] .= $unique_class;
				$attributes['data-smooth-scrolling'] = 'off';
				$attributes['data-scroll-speed'] = '1.5';
				$attributes['data-parallax-image'] = $bg_img;
				$attributes['data-parallax-id'] = '.'.$unique_class;
                break;
            }
        }
  }
  
  if(!empty($args['padding_top'])) {
    if( function_exists('is_numeric' ) ) {
      if (is_numeric($args['padding_top'])) {
        $attributes['style'] .= 'padding-top: '.esc_attr($args['padding_top']).'px; ';
      } else {
         $attributes['style'] .= 'padding-top: '.esc_attr($args['padding_top']).'; ';
      }
    } else {
       $attributes['style'] .= 'padding-top: '.esc_attr($args['padding_top']).'; ';
    }
  }
  if(!empty($args['padding_bottom'])){
    if( function_exists('is_numeric' ) ) {
      if (is_numeric($args['padding_bottom'])) {
        $attributes['style'] .= 'padding-bottom: '.esc_attr($args['padding_bottom']).'px; ';
      } else {
        $attributes['style'] .= 'padding-bottom: '.esc_attr($args['padding_bottom']).'; ';
      }
    } else {
      $attributes['style'] .= 'padding-bottom: '.esc_attr($args['padding_bottom']).'; ';
    }
 }
 
 if(!empty($args['padding_left'])){
   $attributes['style'] .= 'padding-left: '.esc_attr($args['padding_left']).'; ';
 }
 if(!empty($args['padding_right'])){
   $attributes['style'] .= 'padding-right: '.esc_attr($args['padding_right']).'; ';
 }
 if(!empty($args['border_top'])){
   $attributes['style'] .= 'border-top: '.esc_attr($args['border_top']).' solid; ';
 }
 if(!empty($args['border_top_color'])){
   $attributes['style'] .= 'border-top-color: '.$args['border_top_color'].'; ';
 }
 if(!empty($args['border_bottom'])){
   $attributes['style'] .= 'border-bottom: '.esc_attr($args['border_bottom']).' solid; ';
 }
  if(!empty($args['border_bottom_color'])){
   $attributes['style'] .= 'border-bottom-color: '.$args['border_bottom_color'].'; ';
 }

if(!empty($args['custom_row_id'])){
   $attributes['data-row-id'] = $args['custom_row_id'];
 }

if(!empty($args['equal_column_height'])){
	if($args['equal_column_height']=="yes"){
   		$attributes['class'][] = 'equal-column-height';
	}
 }

  return $attributes;
}
add_filter('siteorigin_panels_row_style_attributes', 'create_panels_row_background_styles_attributes', 10, 2);





//////////////////////////////////////////////
//Prebuilt Layouts
//////////////////////////////////////////////

?>