<?php
/**
 * Create Theme Customizer
 *
 * @package create
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function create_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	
	// remove controls
	$wp_customize->remove_control('blogdescription');

	// -- Sanitization Callbacks

	/**
	 * Sanitize boolean
	 *
	 * @param $input
	 *
	 * @return bool
	 */
	function create_sanitize_checkbox( $input ) {
	    if ( $input == 1 ) {
	        return 1;
	    } else {
	        return 0;
	    }
	}

	/**
	 * Sanitize numbers
	 *
	 * @param int $input
	 *
	 * @return int
	 */
	function create_sanitize_number( $input ) {
		if ( is_numeric( $input ) ) {
			return $input;
		} else {
			return '';
		}
	}

	/**
	 * Sanitize banner type
	 *
	 * @param string $input
	 *
	 * @return string
	 */
	function create_sanitize_banner_type( $input ){

		if( 'static' == $input || 'campaign' == $input )
			return $input;
		else
			return '';

	} // create_sanitize_banner_type()

	if ( ! class_exists( 'WP_Customize_Control' ) )
		return NULL;

	/**
	 * Class to add a text area for page and section descriptions
	 */

	class Create_Textarea_Control extends WP_Customize_Control {
		public $type = 'textarea';

		public function render_content() {
			?>
			<label>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<textarea rows="5" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
			</label>
			<?php
		}
	} // Create_Textarea_Control

	/**
	 * Class to add a header to certain sections
	 */
	class Create_Header_Control extends WP_Customize_Control {
		public $type = 'tag';
		public function render_content() {
			?>
			<h3 class="customize-control-title"><?php echo esc_html( $this->label ); ?></h3>
		<?php
		}
	}

	//Text Area Control
	class TTrust_Textarea_Control extends WP_Customize_Control {
		public $type = 'textarea';

		public function render_content() {
			?>
			<label>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<textarea rows="5" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
			</label>
			<?php
		}
	}
	
	//Disabled Control
	class TTrust_Disabled_Control extends WP_Customize_Control {
		public $type = 'disabled';

		public function render_content() {
			?>
			<p class="customize-control-disabled"><?php echo esc_html( $this->label ); ?></p>
			<?php
		}
	}
	
	
	// -- General --------------------------------------------------------------------------------------------------

	$wp_customize->add_panel( 'create_general', array(
		'priority'		 => 1,
	    'title'     	 => __( 'General', 'create' )
	) );
	
	// -- Loader
	
	
	
	$wp_customize->add_section( 'create_loader', array(
		'priority'		 => 1,
	    'title'     	 => __( 'Loader', 'create' ),
		'panel'			=> 'create_general'
	) );
	
$wp_customize->add_setting( 'create_loader_disabled' , array(
    'type' 				=> 'theme_mod',
    'transport' 		=> 'refresh',
    'sanitize_callback'	=> 'esc_html'
) );

$wp_customize->add_control( new TTrust_Disabled_Control( $wp_customize, 'create_loader_disabled', array(
	'label'        => __('These options are available in the full version.', 'create'),
	'section'			=> 'create_loader',
	'settings'   => 'create_loader_disabled',
	'priority'   => 62
) ) );
	
	// -- Layout --------------------------------------------------------------------------------------------------
	
	$wp_customize->add_section( 'create_layout', array(
		'priority'		 => 3,
	    'title'     	 => __( 'Layout', 'create' )
	) );
	
	$wp_customize->add_setting( 'create_site_width' , array(
	    'default'     		=> __( 'full-width', 'create' ),
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_site_width', array(
		'type'      => 'select',
		'label'     => __( 'Site Container', 'create' ),
		'section'   => 'create_layout',
		'settings'  => 'create_site_width',
		'choices'   => array(
		            'full-width' => 'Full Width',
		            'boxed' => 'Boxed'
		        ),
		'priority'   => 31
	) );
	
	
	
	// -- Header & Navigation --------------------------------------------------------------------------------------------------

	$wp_customize->add_panel( 'create_header_navigation', array(
		'priority'		 => 4,
	    'title'     	 => __( 'Header & Navigation', 'create' )
	) );
	
	// -- Logos
	
	$wp_customize->add_section( 'create_logos', array(
		'priority'		 => 1,
	    'title'     	 => __( 'Logos', 'create' ),
		'panel'			=> 'create_header_navigation'
	) );
	
	$wp_customize->add_setting( 'create_logo_top' , array(
	    'default'   		=> '',
	    'type'				=> 'theme_mod',
	    'transport'			=> 'refresh',
	    'sanitize_callback'	=> 'esc_url_raw'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'create_top_logo', array(
		'label'      => __('Header Logo - Dark', 'create'),
		'section'    => 'create_logos',
		'settings'   => 'create_logo_top',
	    'priority'   => 1
	) ) );
	
	$wp_customize->add_setting( 'create_logo_top_width' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_logo_top_width', array(
		'label'     => __( 'Header Logo Width - Dark', 'create' ),
		'type'      => 'text',
		'description'     => __( 'Enter the actual width of your logo image in pixels. Used for retina displays.', 'create' ),
		'section'   => 'create_logos',
		'settings'  => 'create_logo_top_width',
		'priority'   => 2
	) );
	
	
	
	$wp_customize->add_setting( 'create_logo_mobile_width' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_logo_mobile_width', array(
		'label'     => __( 'Mobile Logo Max Width ', 'create' ),
		'type'      => 'text',
		'description'     => __( 'Set the max width of logo for mobile.', 'create' ),
		'section'   => 'create_logos',
		'settings'  => 'create_logo_mobile_width',
		'priority'   => 5
	) );
	
	/*
	$wp_customize->add_setting( 'create_logo_side' , array(
	    'default'   		=> '',
	    'type'				=> 'theme_mod',
	    'transport'			=> 'refresh',
	    'sanitize_callback'	=> 'esc_url_raw'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'create_top_side', array(
		'label'      => __('Side Header Logo', 'create'),
		'section'    => 'create_logos',
		'settings'   => 'create_logo_side',
	    'priority'   => 5
	) ) );
	
	$wp_customize->add_setting( 'create_logo_side_width' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_logo_side_width', array(
		'label'     => __( 'Side Header Logo Width', 'create' ),
		'type'      => 'text',
		'description'     => __( 'Enter the actual width of your logo image in pixels. Used for retina displays.', 'create' ),
		'section'   => 'create_logos',
		'settings'  => 'create_logo_side_width',
		'priority'   => 6
	) );
	*/
	
	$wp_customize->add_setting( 'create_favicon' , array(
	    'default'   		=> '',
	    'type'				=> 'theme_mod',
	    'transport'			=> 'refresh',
	    'sanitize_callback'	=> 'esc_url_raw'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'create_favicon', array(
		'label'      => __('Favicon', 'create'),
		'section'    => 'create_logos',
		'settings'   => 'create_favicon',
	    'priority'   => 7
	) ) );
	
	
	
	// -- Position & Style
	
	$wp_customize->add_section( 'create_header', array(
		'priority'		 => 1,
	    'title'     	 => __( 'Position & Style', 'create' ),
		'panel'			=> 'create_header_navigation'
	) );
	
	$wp_customize->add_setting( 'create_top_header_height' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_top_header_height', array(
		'label'     => __( 'Top Header Height', 'create' ),
		'type'      => 'text',
		'description'     => __( 'Enter the height of your top header in pixels.', 'create' ),
		'section'   => 'create_header',
		'settings'  => 'create_top_header_height',
		'priority'   => 2.7
	) );
	

	
	// -- Slide Panel	
	
	$wp_customize->add_section( 'create_slide_panel', array(
		'priority'		 => 2,
	    'title'     	 => __( 'Slide Panel', 'create' ),
		'panel'			=> 'create_header_navigation'
	) );
	
	$wp_customize->add_setting( 'create_slide_panel_disabled' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( new TTrust_Disabled_Control( $wp_customize, 'create_slide_panel_disabled', array(
		'label'        => __('These options are available in the full version.', 'create'),
		'section'			=> 'create_slide_panel',
		'settings'   => 'create_slide_panel_disabled',
		'priority'   => 62
	) ) );
	
	
	// -- Search
	
	$wp_customize->add_section( 'create_header_search', array(
		'priority'		 => 3,
	    'title'     	 => __( 'Search', 'create' ),
		'panel'			=> 'create_header_navigation'
	) );
	
	$wp_customize->add_setting( 'create_enable_header_search' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_enable_header_search', array(
		'type'      => 'select',
		'label'     => __( 'Enable Search Icon', 'create' ),
		'description'     => __( 'Shows the search icon in the top header.', 'create' ),
		'section'   => 'create_header_search',
		'settings'  => 'create_enable_header_search',
		'choices'   => array(
		            'no' => 'No',
					'yes' => 'Yes'
		        ),
		'priority'   => 1
	) );
	
	// -- Scroll To Top
	
	$wp_customize->add_section( 'create_header_scroll_to_top', array(
		'priority'		 => 3.5,
	    'title'     	 => __( 'Scroll to Top Button', 'create' ),
		'panel'			=> 'create_header_navigation'
	) );
	
	
	$wp_customize->add_setting( 'create_header_scroll_to_top_disabled' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( new TTrust_Disabled_Control( $wp_customize, 'create_header_scroll_to_top_disabled', array(
		'label'        => __('These options are available in the full version.', 'create'),
		'section'			=> 'create_header_scroll_to_top',
		'settings'   => 'create_header_scroll_to_top_disabled',
		'priority'   => 62
	) ) );
	
	// -- Mobile
	
	$wp_customize->add_section( 'create_mobile_header', array(
		'priority'		 => 4,
	    'title'     	 => __( 'Mobile', 'create' ),
		'panel'			=> 'create_header_navigation'
	) );
	
	$wp_customize->add_setting( 'create_mobile_header_breakpoint' , array(
	    'default'   		=> '',
	    'type'				=> 'theme_mod',
	    'transport'			=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_mobile_header_breakpoint', array(
		'label'     => __( 'Custom Mobile Breakpoint', 'create' ),
		'type'      => 'text',
		'description'     => __( 'Enter a custom mobile break point in pixels. (ex. 590)', 'create' ),
		'section'   => 'create_mobile_header',
		'settings'  => 'create_mobile_header_breakpoint',
		'priority'   => 1
	) );
	
	// -- Page Titles --------------------------------------------------------------------------------------------------
	
	$wp_customize->add_section( 'create_page_titles', array(
		'priority'		 => 4.2,
	    'title'     	 => __( 'Page Titles', 'create' )
	) );
	
	$wp_customize->add_setting( 'create_page_titles_disabled' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( new TTrust_Disabled_Control( $wp_customize, 'create_page_titles_disabled', array(
		'label'        => __('These options are available in the full version.', 'create'),
		'section'			=> 'create_page_titles',
		'settings'   => 'create_page_titles_disabled',
		'priority'   => 62
	) ) );
	
	// -- Blog --------------------------------------------------------------------------------------------------

	$wp_customize->add_panel( 'create_blog', array(
		'priority'		 => 4.5,
	    'title'     	 => __( 'Blog', 'create' )
	) );
	
	// -- Meta
	
	$wp_customize->add_section( 'create_post_meta', array(
		'priority'		 => 1,
	    'title'     	 => __( 'Post Meta', 'create' ),
		'panel'			=> 'create_blog'
	) );
	
	$wp_customize->add_setting( 'create_show_meta_date' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_show_meta_date', array(
		'type'      => 'select',
		'label'     => __( 'Show Date', 'create' ),
		'description'     => __( 'Show the date on each post', 'create' ),
		'section'   => 'create_post_meta',
		'settings'  => 'create_show_meta_date',
		'choices'   => array(
					'yes' => 'Yes',
		            'no' => 'No'
		        ),
		'priority'   => 1
	) );
	
	$wp_customize->add_setting( 'create_show_meta_author' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_show_meta_author', array(
		'type'      => 'select',
		'label'     => __( 'Show Author', 'create' ),
		'description'     => __( 'Show the author on each post.', 'create' ),
		'section'   => 'create_post_meta',
		'settings'  => 'create_show_meta_author',
		'choices'   => array(
					'yes' => 'Yes',
		            'no' => 'No'
		        ),
		'priority'   => 1
	) );
	
	$wp_customize->add_setting( 'create_show_meta_categories' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_show_meta_categories', array(
		'type'      => 'select',
		'label'     => __( 'Show Categories', 'create' ),
		'description'     => __( 'Show the categories on each post.', 'create' ),
		'section'   => 'create_post_meta',
		'settings'  => 'create_show_meta_categories',
		'choices'   => array(
					'yes' => 'Yes',
		            'no' => 'No'
		        ),
		'priority'   => 1
	) );
	
	$wp_customize->add_setting( 'create_show_meta_comments' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_show_meta_comments', array(
		'type'      => 'select',
		'label'     => __( 'Show Comment Count', 'create' ),
		'description'     => __( 'Show the comment count on each post.', 'create' ),
		'section'   => 'create_post_meta',
		'settings'  => 'create_show_meta_comments',
		'choices'   => array(
					'yes' => 'Yes',
		            'no' => 'No'
		        ),
		'priority'   => 1
	) );
	
	
	// -- Archive Layout
	
	$wp_customize->add_section( 'create_archives', array(
		'priority'		 => 2,
	    'title'     	 => __( 'Archives', 'create' ),
		'panel'			=> 'create_blog'
	) );	
	
	$wp_customize->add_setting( 'create_archive_layout' , array(
	    'default'     		=> __( 'full-width', 'create' ),
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_archive_layout', array(
		'type'      => 'select',
		'label'     => __( 'Archive Layout', 'create' ),
		'section'   => 'create_archives',
		'settings'  => 'create_archive_layout',
		'choices'   => array(
		            'standard' => 'Standard',
					'full-width' => 'Full Width',
		            'masonry' => 'Masonry',
					'masonry-full-width' => 'Masonry Full Width',
		        ),
		'priority'   => 1
	) );
	
	$wp_customize->add_setting( 'create_archive_show_excerpt' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_archive_show_excerpt', array(
		'type'      => 'select',
		'label'     => __( 'Show Excerpts', 'create' ),
		'section'   => 'create_archives',
		'settings'  => 'create_archive_show_excerpt',
		'choices'   => array(
					'yes' => 'Yes',
		            'no' => 'No'
		        ),
		'priority'   => 2
	) );
	
	
	// -- Shop --------------------------------------------------------------------------------------------------

	$wp_customize->add_section( 'create_shop', array(
		'priority'		 => 4.7,
	    'title'     	 => __( 'Shop', 'create' )
	) );
	
	
	$wp_customize->add_setting( 'create_shop_disabled' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( new TTrust_Disabled_Control( $wp_customize, 'create_shop_disabled', array(
		'label'        => __('These options are available in the full version.', 'create'),
		'section'			=> 'create_shop',
		'settings'   => 'create_shop_disabled',
		'priority'   => 62
	) ) );	
	
	// -- Typography --------------------------------------------------------------------------------------------------

	$wp_customize->add_section( 'create_typography', array(
		'priority'		 => 4.8,
	    'title'     	 => __( 'Typography', 'create' )
	) );
	
	
	$wp_customize->add_setting( 'create_typography_disabled' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( new TTrust_Disabled_Control( $wp_customize, 'create_typography_disabled', array(
		'label'        => __('These options are available in the full version.', 'create'),
		'section'			=> 'create_typography',
		'settings'   => 'create_typography_disabled',
		'priority'   => 62
	) ) );
	
	
	
	// -- Social Sharing --------------------------------------------------------------------------------------------------
	
	$wp_customize->add_section( 'create_social_sharing', array(
		'priority'		 => 5,
	    'title'     	 => __( 'Social Sharing', 'create' )
	) );
	
	$wp_customize->add_setting( 'create_social_sharing_disabled' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( new TTrust_Disabled_Control( $wp_customize, 'create_social_sharing_disabled', array(
		'label'        => __('These options are available in the full version.', 'create'),
		'section'			=> 'create_social_sharing',
		'settings'   => 'create_social_sharing_disabled',
		'priority'   => 62
	) ) );
	
	// -- Other Styles Panel
	
	$wp_customize->add_section( 'create_other_styles', array(
		'priority'		 => 5.5,
	    'title'     	 => __( 'Other Styles', 'create' )
	) );
	
	$wp_customize->add_setting( 'create_other_styles_disabled' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );

	$wp_customize->add_control( new TTrust_Disabled_Control( $wp_customize, 'create_other_styles_disabled', array(
		'label'        => __('These options are available in the full version.', 'create'),
		'section'			=> 'create_other_styles',
		'settings'   => 'create_other_styles_disabled',
		'priority'   => 62
	) ) );
	
	
	// -- Custom  CSS Section

	$wp_customize->add_section( 'create_css' , array(
	    'title'     	=> __( 'Custom CSS', 'create' ),
	    'description'	=> __('Add your own custom CSS.', 'create'),
	    'priority'   	=> 59,
	) );
	
	$wp_customize->add_setting( 'create_custom_css' , array(
	    'default'     => __('', 'create'),
	    'type' => 'theme_mod',
	    'transport' => 'refresh',
	    'sanitize_callback'	 => 'wp_kses_post'
	) );

	$wp_customize->add_control( new TTrust_Textarea_Control( $wp_customize, 'create_custom_css', array(
		'label'        => __('CSS', 'create'),
		'section'    => 'create_css',
		'settings'   => 'create_custom_css',
		'priority'   => 62
	) ) );

	// -- Footer Section -----------------------------------

	$wp_customize->add_panel( 'create_footer' , array(
	    'title'      => __( 'Footer', 'port' ),
	    'priority'   => 62.5,
	) );
	
	$wp_customize->add_section( 'create_footer_layout', array(
		'priority'		 => 1,
		'panel'		 => 'create_footer',
	    'title'     	 => __( 'Layout', 'create' )
	) );
	
	$wp_customize->add_setting( 'create_footer_columns' , array(
	    'type' 				=> 'theme_mod',
	    'transport' 		=> 'refresh',
	    'sanitize_callback'	=> 'esc_html'
	) );
	
	$wp_customize->add_control( 'create_footer_columns', array(
		'type'      => 'select',
		'label'     => __( 'Widget Columns', 'create' ),
		'section'   => 'create_footer_layout',
		'settings'  => 'create_footer_columns',
		'choices'   => array(
					'3' => '3',
					'4' => '4',
					'1' => '1',
		            '2' => '2',
					'5' => '5'
		        ),
		'priority'   => 1
	) );
	
	$wp_customize->add_section( 'create_footer_style', array(
		'priority'		 => 2,
		'panel'		 => 'create_footer',
	    'title'     	 => __( 'Style', 'create' )
	) );
	
	// Footer Background Color
	$wp_customize->add_setting( 'create_footer_bg_color' );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'create_footer_bg_color', array(
			'label'      => __( 'Background Color', 'create' ),
			'section'    => 'create_footer_style',
			'settings'   => 'create_footer_bg_color',
			'priority'   => 1
		) )
	);
	
	// Footer Widget Title Color
	$wp_customize->add_setting( 'create_footer_widget_title_color' );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'create_footer_widget_title_color', array(
			'label'      => __( 'Widget Title Color', 'create' ),
			'section'    => 'create_footer_style',
			'settings'   => 'create_footer_widget_title_color',
			'priority'   => 1.5
		) )
	);
	
	// Footer Text Color
	$wp_customize->add_setting( 'create_footer_text_color' );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'create_footer_text_color', array(
			'label'      => __( 'Text Color', 'create' ),
			'section'    => 'create_footer_style',
			'settings'   => 'create_footer_text_color',
			'priority'   => 2
		) )
	);
	
	// Footer Link Color
	$wp_customize->add_setting( 'create_footer_link_color' );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'create_footer_link_color', array(
			'label'      => __( 'Link Color', 'create' ),
			'section'    => 'create_footer_style',
			'settings'   => 'create_footer_link_color',
			'priority'   => 3
		) )
	);

	// Footer Link Hover Color
	$wp_customize->add_setting( 'create_footer_link_hover_color' );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'create_footer_link_hover_color', array(
			'label'      => __( 'Link Hover Color', 'create' ),
			'section'    => 'create_footer_style',
			'settings'   => 'create_footer_link_hover_color',
			'priority'   => 4
		) )
	);
	
	// Footer Content
	$wp_customize->add_section( 'create_footer_text', array(
		'priority'		 => 2,
		'panel'		 => 'create_footer',
	    'title'     	 => __( 'Content', 'create' )
	) );

	// Left Footer Text (Custom Control)
	$wp_customize->add_setting( 'create_footer_left' , array(
	    'default'     => '',
	    'type' => 'theme_mod',
	    'transport' => 'refresh',
	    'sanitize_callback'	 => 'wp_kses_post'
	) );

	$wp_customize->add_control( new Create_Textarea_Control( $wp_customize, 'footer_left', array(
	    'label'   => __('Primary Footer Text', 'port'),
	    'section' => 'create_footer_text',
	    'settings'   => 'create_footer_left',
	    'priority'   => 71
	) ) );

	// Right Footer Text (Custom Control)
	$wp_customize->add_setting( 'create_footer_right' , array(
	    'default'     => '',
	    'type' => 'theme_mod',
	    'transport' => 'refresh',
	    'sanitize_callback'	 => 'wp_kses_post'
	) );

	$wp_customize->add_control( new Create_Textarea_Control( $wp_customize, 'footer_right', array(
	    'label'   => __('Secondary Footer Text', 'port'),
	    'section' => 'create_footer_text',
	    'settings'   => 'create_footer_right',
	    'priority'   => 72
	) ) );

}
add_action( 'customize_register', 'create_customize_register' );